@@ -1,19 +1,16 @@
 <?php
-
 /**
  * `RESTORE` statement.
  */
 
+declare(strict_types=1);
+
 namespace PhpMyAdmin\SqlParser\Statements;
 
 /**
  * `RESTORE` statement.
  *
  * RESTORE TABLE tbl_name [, tbl_name] ... FROM '/path/to/backup/directory'
- *
- * @category   Statements
- *
- * @license    https://www.gnu.org/licenses/gpl-2.0.txt GPL-2.0+
  */
 class RestoreStatement extends MaintenanceStatement
 {
@@ -22,12 +19,12 @@ class RestoreStatement extends MaintenanceStatement
      *
      * @var array
      */
-    public static $OPTIONS = array(
+    public static $OPTIONS = [
         'TABLE' => 1,
 
-        'FROM' => array(
+        'FROM' => [
             2,
             'var',
-        )
-    );
+        ],
+    ];
 }
