@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace PhpMyAdmin\SqlParser\Tests\Builder;
 
 use PhpMyAdmin\SqlParser\Components\Condition;
@@ -15,7 +17,7 @@ class StatementTest extends TestCase
     {
         $stmt = new SelectStatement();
 
-        $stmt->options = new OptionsArray(array('DISTINCT'));
+        $stmt->options = new OptionsArray(['DISTINCT']);
 
         $stmt->expr[] = new Expression('sakila', 'film', 'film_id', 'fid');
         $stmt->expr[] = new Expression('COUNT(film_id)');
