@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace PhpMyAdmin\SqlParser\Tests\Components;
 
 use PhpMyAdmin\SqlParser\Components\ExpressionArray;
@@ -13,11 +15,9 @@ class ExpressionArrayTest extends TestCase
         $component = ExpressionArray::parse(
             new Parser(),
             $this->getTokensList('(expr)'),
-            array(
-                'breakOnParentheses' => true
-            )
+            ['breakOnParentheses' => true]
         );
-        $this->assertEquals(array(), $component);
+        $this->assertEquals([], $component);
     }
 
     public function testParse2()
@@ -25,9 +25,7 @@ class ExpressionArrayTest extends TestCase
         $component = ExpressionArray::parse(
             new Parser(),
             $this->getTokensList('(expr) +'),
-            array(
-                'parenthesesDelimited' => true
-            )
+            ['parenthesesDelimited' => true]
         );
         $this->assertCount(1, $component);
         $this->assertEquals('(expr)', $component[0]->expr);
