@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace PhpMyAdmin\SqlParser\Tests\Components;
 
 use PhpMyAdmin\SqlParser\Components\Expression;
@@ -12,11 +14,11 @@ class GroupKeywordTest extends TestCase
     {
         $this->assertEquals(
             GroupKeyword::build(
-                array(
+                [
                     new GroupKeyword(new Expression('a')),
                     new GroupKeyword(new Expression('b')),
                     new GroupKeyword(new Expression('c')),
-                )
+                ]
             ),
             'a, b, c'
         );
