@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace PhpMyAdmin\SqlParser\Tests\Components;
 
 use PhpMyAdmin\SqlParser\Components\JoinKeyword;
@@ -23,7 +25,7 @@ class JoinKeywordTest extends TestCase
         $this->assertCount(1, $component);
         $this->assertEquals('table2', $component[0]->expr->expr);
         $this->assertNull($component[0]->on);
-        $this->assertEquals(array('id'), $component[0]->using->values);
+        $this->assertEquals(['id'], $component[0]->using->values);
     }
 
     public function testBuild()
