@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace PhpMyAdmin\SqlParser\Tests\Components;
 
 use PhpMyAdmin\SqlParser\Components\Limit;
@@ -20,9 +22,9 @@ class LimitTest extends TestCase
     }
 
     /**
-     * @dataProvider parseProvider
-     *
      * @param mixed $test
+     *
+     * @dataProvider parseProvider
      */
     public function testParse($test)
     {
@@ -31,9 +33,9 @@ class LimitTest extends TestCase
 
     public function parseProvider()
     {
-        return array(
-            array('parser/parseLimitErr1'),
-            array('parser/parseLimitErr2')
-        );
+        return [
+            ['parser/parseLimitErr1'],
+            ['parser/parseLimitErr2'],
+        ];
     }
 }
