@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace PhpMyAdmin\SqlParser\Tests\Components;
 
 use PhpMyAdmin\SqlParser\Components\Expression;
@@ -12,10 +14,10 @@ class OrderKeywordTest extends TestCase
     {
         $this->assertEquals(
             OrderKeyword::build(
-                array(
+                [
                     new OrderKeyword(new Expression('a'), 'ASC'),
-                    new OrderKeyword(new Expression('b'), 'DESC')
-                )
+                    new OrderKeyword(new Expression('b'), 'DESC'),
+                ]
             ),
             'a ASC, b DESC'
         );
