@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace PhpMyAdmin\SqlParser\Tests\Components;
 
 use PhpMyAdmin\SqlParser\Components\Expression;
@@ -13,12 +15,12 @@ class ReferenceTest extends TestCase
     {
         $component = Reference::parse(new Parser(), $this->getTokensList('tbl (id)'));
         $this->assertEquals('tbl', $component->table->table);
-        $this->assertEquals(array('id'), $component->columns);
+        $this->assertEquals(['id'], $component->columns);
     }
 
     public function testBuild()
     {
-        $component = new Reference(new Expression('`tbl`'), array('id'));
+        $component = new Reference(new Expression('`tbl`'), ['id']);
         $this->assertEquals('`tbl` (`id`)', Reference::build($component));
     }
 }
