@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace PhpMyAdmin\SqlParser\Tests\Misc;
 
 use PhpMyAdmin\SqlParser\Tests\TestCase;
@@ -7,9 +9,9 @@ use PhpMyAdmin\SqlParser\Tests\TestCase;
 class BugsTest extends TestCase
 {
     /**
-     * @dataProvider bugProvider
-     *
      * @param mixed $test
+     *
+     * @dataProvider bugProvider
      */
     public function testBug($test)
     {
@@ -18,15 +20,15 @@ class BugsTest extends TestCase
 
     public function bugProvider()
     {
-        return array(
-            array('bugs/gh9'),
-            array('bugs/gh14'),
-            array('bugs/gh16'),
-            array('bugs/pma11800'),
-            array('bugs/pma11836'),
-            array('bugs/pma11843'),
-            array('bugs/pma11867'),
-            array('bugs/pma11879')
-        );
+        return [
+            ['bugs/gh9'],
+            ['bugs/gh14'],
+            ['bugs/gh16'],
+            ['bugs/pma11800'],
+            ['bugs/pma11836'],
+            ['bugs/pma11843'],
+            ['bugs/pma11867'],
+            ['bugs/pma11879'],
+        ];
     }
 }
