@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace PhpMyAdmin\SqlParser\Tests\Misc;
 
 use PhpMyAdmin\SqlParser\Tests\TestCase;
@@ -7,9 +9,9 @@ use PhpMyAdmin\SqlParser\Tests\TestCase;
 class ParameterTest extends TestCase
 {
     /**
-     * @dataProvider parameterProvider
-     *
      * @param mixed $test
+     *
+     * @dataProvider parameterProvider
      */
     public function testParameter($test)
     {
@@ -18,8 +20,8 @@ class ParameterTest extends TestCase
 
     public function parameterProvider()
     {
-        return array(
-            array('misc/parseParameter')
-        );
+        return [
+            ['misc/parseParameter'],
+        ];
     }
 }
