@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace PhpMyAdmin\SqlParser\Tests\Parser;
 
 use PhpMyAdmin\SqlParser\Tests\TestCase;
@@ -7,9 +9,9 @@ use PhpMyAdmin\SqlParser\Tests\TestCase;
 class CallStatementTest extends TestCase
 {
     /**
-     * @dataProvider callProvider
-     *
      * @param mixed $test
+     *
+     * @dataProvider callProvider
      */
     public function testCall($test)
     {
@@ -18,10 +20,10 @@ class CallStatementTest extends TestCase
 
     public function callProvider()
     {
-        return array(
-            array('parser/parseCall'),
-            array('parser/parseCall2'),
-            array('parser/parseCall3')
-        );
+        return [
+            ['parser/parseCall'],
+            ['parser/parseCall2'],
+            ['parser/parseCall3'],
+        ];
     }
 }
