@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace PhpMyAdmin\SqlParser\Tests\Parser;
 
 use PhpMyAdmin\SqlParser\Tests\TestCase;
@@ -7,9 +9,9 @@ use PhpMyAdmin\SqlParser\Tests\TestCase;
 class ExplainStatementTest extends TestCase
 {
     /**
-     * @dataProvider explainProvider
-     *
      * @param mixed $test
+     *
+     * @dataProvider explainProvider
      */
     public function testExplain($test)
     {
@@ -18,8 +20,8 @@ class ExplainStatementTest extends TestCase
 
     public function explainProvider()
     {
-        return array(
-            array('parser/parseExplain')
-        );
+        return [
+            ['parser/parseExplain'],
+        ];
     }
 }
