@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace PhpMyAdmin\SqlParser\Tests\Parser;
 
 use PhpMyAdmin\SqlParser\Parser;
@@ -16,9 +18,9 @@ class LoadStatementTest extends TestCase
     }
 
     /**
-     * @dataProvider loadProvider
-     *
      * @param mixed $test
+     *
+     * @dataProvider loadProvider
      */
     public function testLoad($test)
     {
@@ -27,19 +29,19 @@ class LoadStatementTest extends TestCase
 
     public function loadProvider()
     {
-        return array(
-            array('parser/parseLoad1'),
-            array('parser/parseLoad2'),
-            array('parser/parseLoad3'),
-            array('parser/parseLoad4'),
-            array('parser/parseLoad5'),
-            array('parser/parseLoad6'),
-            array('parser/parseLoadErr1'),
-            array('parser/parseLoadErr2'),
-            array('parser/parseLoadErr3'),
-            array('parser/parseLoadErr4'),
-            array('parser/parseLoadErr5'),
-            array('parser/parseLoadErr6')
-        );
+        return [
+            ['parser/parseLoad1'],
+            ['parser/parseLoad2'],
+            ['parser/parseLoad3'],
+            ['parser/parseLoad4'],
+            ['parser/parseLoad5'],
+            ['parser/parseLoad6'],
+            ['parser/parseLoadErr1'],
+            ['parser/parseLoadErr2'],
+            ['parser/parseLoadErr3'],
+            ['parser/parseLoadErr4'],
+            ['parser/parseLoadErr5'],
+            ['parser/parseLoadErr6'],
+        ];
     }
 }
