@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace PhpMyAdmin\SqlParser\Tests\Parser;
 
 use PhpMyAdmin\SqlParser\Tests\TestCase;
@@ -7,9 +9,9 @@ use PhpMyAdmin\SqlParser\Tests\TestCase;
 class PurgeStatementTest extends TestCase
 {
     /**
-     * @dataProvider purgeProvider
-     *
      * @param mixed $test
+     *
+     * @dataProvider purgeProvider
      */
     public function testPurge($test)
     {
@@ -18,14 +20,14 @@ class PurgeStatementTest extends TestCase
 
     public function purgeProvider()
     {
-        return array(
-            array('parser/parsePurge'),
-            array('parser/parsePurge2'),
-            array('parser/parsePurge3'),
-            array('parser/parsePurge4'),
-            array('parser/parsePurgeErr'),
-            array('parser/parsePurgeErr2'),
-            array('parser/parsePurgeErr3')
-        );
+        return [
+            ['parser/parsePurge'],
+            ['parser/parsePurge2'],
+            ['parser/parsePurge3'],
+            ['parser/parsePurge4'],
+            ['parser/parsePurgeErr'],
+            ['parser/parsePurgeErr2'],
+            ['parser/parsePurgeErr3'],
+        ];
     }
 }
