@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace PhpMyAdmin\SqlParser\Tests\Parser;
 
 use PhpMyAdmin\SqlParser\Tests\TestCase;
@@ -7,9 +9,9 @@ use PhpMyAdmin\SqlParser\Tests\TestCase;
 class RenameStatementTest extends TestCase
 {
     /**
-     * @dataProvider renameProvider
-     *
      * @param mixed $test
+     *
+     * @dataProvider renameProvider
      */
     public function testRename($test)
     {
@@ -18,14 +20,14 @@ class RenameStatementTest extends TestCase
 
     public function renameProvider()
     {
-        return array(
-            array('parser/parseRename'),
-            array('parser/parseRename2'),
-            array('parser/parseRenameErr1'),
-            array('parser/parseRenameErr2'),
-            array('parser/parseRenameErr3'),
-            array('parser/parseRenameErr4'),
-            array('parser/parseRenameErr5')
-        );
+        return [
+            ['parser/parseRename'],
+            ['parser/parseRename2'],
+            ['parser/parseRenameErr1'],
+            ['parser/parseRenameErr2'],
+            ['parser/parseRenameErr3'],
+            ['parser/parseRenameErr4'],
+            ['parser/parseRenameErr5'],
+        ];
     }
 }
