@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace PhpMyAdmin\SqlParser\Tests\Parser;
 
 use PhpMyAdmin\SqlParser\Tests\TestCase;
@@ -7,9 +9,9 @@ use PhpMyAdmin\SqlParser\Tests\TestCase;
 class RestoreStatementTest extends TestCase
 {
     /**
-     * @dataProvider restoreProvider
-     *
      * @param mixed $test
+     *
+     * @dataProvider restoreProvider
      */
     public function testRestore($test)
     {
@@ -18,8 +20,8 @@ class RestoreStatementTest extends TestCase
 
     public function restoreProvider()
     {
-        return array(
-            array('parser/parseRestore')
-        );
+        return [
+            ['parser/parseRestore'],
+        ];
     }
 }
