@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace PhpMyAdmin\SqlParser\Tests\Parser;
 
 use PhpMyAdmin\SqlParser\Tests\TestCase;
@@ -7,9 +9,9 @@ use PhpMyAdmin\SqlParser\Tests\TestCase;
 class TransactionStatementTest extends TestCase
 {
     /**
-     * @dataProvider transactionProvider
-     *
      * @param mixed $test
+     *
+     * @dataProvider transactionProvider
      */
     public function testTransaction($test)
     {
@@ -18,11 +20,11 @@ class TransactionStatementTest extends TestCase
 
     public function transactionProvider()
     {
-        return array(
-            array('parser/parseTransaction'),
-            array('parser/parseTransaction2'),
-            array('parser/parseTransaction3'),
-            array('parser/parseTransactionErr1')
-        );
+        return [
+            ['parser/parseTransaction'],
+            ['parser/parseTransaction2'],
+            ['parser/parseTransaction3'],
+            ['parser/parseTransactionErr1'],
+        ];
     }
 }
