@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace PhpMyAdmin\SqlParser\Tests\Parser;
 
 use PhpMyAdmin\SqlParser\Tests\TestCase;
@@ -7,9 +9,9 @@ use PhpMyAdmin\SqlParser\Tests\TestCase;
 class UpdateStatementTest extends TestCase
 {
     /**
-     * @dataProvider updateProvider
-     *
      * @param mixed $test
+     *
+     * @dataProvider updateProvider
      */
     public function testUpdate($test)
     {
@@ -18,11 +20,11 @@ class UpdateStatementTest extends TestCase
 
     public function updateProvider()
     {
-        return array(
-            array('parser/parseUpdate'),
-            array('parser/parseUpdate2'),
-            array('parser/parseUpdate3'),
-            array('parser/parseUpdateErr')
-        );
+        return [
+            ['parser/parseUpdate'],
+            ['parser/parseUpdate2'],
+            ['parser/parseUpdate3'],
+            ['parser/parseUpdateErr'],
+        ];
     }
 }
